@@ -1,3 +1,4 @@
+from ._base_inferer import BaseInferer
 from .folder_dataset import FolderDataset
 from .post_processor import PostProcessor
 from .predictor import Predictor
@@ -5,6 +6,7 @@ from .resize_inferer import ResizeInferer
 from .sliding_window_inferer import SlidingWindowInferer
 
 __all__ = [
+    "BaseInferer",
     "Predictor",
     "PostProcessor",
     "ResizeInferer",
