@@ -8,6 +8,9 @@ class Loss(nn.Module):
     def __init__(
         self,
         name: str,
+        apply_sd: bool = False,
+        apply_ls: bool = False,
+        apply_svls: bool = False,
         edge_weight: float = None,
         class_weights: torch.Tensor = None,
         **kwargs,
@@ -18,6 +21,13 @@ class Loss(nn.Module):
         -----------
             name : str
                 Name of the loss function.
+            apply_sd : bool, default=False
+                If True, Spectral decoupling regularization will be applied  to the
+                loss matrix.
+            apply_ls : bool, default=False
+                If True, Label smoothing will be applied to the target.
+            apply_svls : bool, default=False
+                If True, spatially varying label smoothing will be applied to the target
             edge_weight : float, default=none
                 Weight that is added to object borders.
             class_weights : torch.Tensor, default=None
@@ -36,7 +46,12 @@ class Loss(nn.Module):
             )
 
         self.loss = SEG_LOSS_LOOKUP[name](
-            edge_weight=edge_weight, class_weights=class_weights, **kwargs
+            apply_sd=apply_sd,
+            apply_ls=apply_ls,
+            apply_svls=apply_svls,
+            edge_weight=edge_weight,
+            class_weights=class_weights,
+            **kwargs,
         )
 
     def forward(
